'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

var _path = require('path');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i]; return arr2; } else { return Array.from(arr); } }

const debugLog = (0, _debug2.default)('mocha-parallel-tests:cache');

/**
 * It's important to watch for require.cache during mocha tests run
 * This helper is here to help: it starts watching required files when
 * you call start(), stops watching when you call stop() and flushes them
 * from require.cache when you call flushRequireCache()
 */
const difference = (a, b) => {
    const aSet = new Set(a);
    const bSet = new Set(b);

    const diffElementsSet = new Set([].concat(_toConsumableArray(a.filter(x => !bSet.has(x))), _toConsumableArray(b.filter(x => !aSet.has(x)))));

    return [].concat(_toConsumableArray(diffElementsSet));
};

class RequireCacheWatcher {
    start() {
        this._cached = this._getRequireCache();
        this._namedMarks = new Map();
    }

    getStateMark() {
        const mark = `mark_${Date.now()}_${Math.random()}`;
        this._namedMarks.set(mark, this._getRequireCache());

        return mark;
    }

    flushRequireCache(stateMark) {
        const markRelatedCache = this._namedMarks.get(stateMark);
        const diff = difference(this._cached, markRelatedCache);

        for (let filePath of diff) {
            const isInternalDependency = this._isInternalDependency(filePath);

            if (!isInternalDependency && !/\.node$/.test(filePath)) {
                debugLog(`Flush ${filePath} from cache`);
                delete require.cache[filePath];
            }
        }
    }

    _getRequireCache() {
        return Object.keys(require.cache);
    }

    _isInternalDependency(filePath) {
        // "../../node_modules/moment/..." -> "mode_modules/moment/..."
        const relativePath = (0, _path.relative)(__filename, filePath).replace(/\.\.\//g, '');
        return relativePath.indexOf('node_modules', 1) !== -1;
    }
}

exports.default = RequireCacheWatcher;
module.exports = exports['default'];