'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const mocha_1 = require("mocha");
const reporter_1 = require("./lib/reporter");
const runner_1 = require("./lib/runner");
const watcher_1 = require("./lib/watcher");
class MochaParallelTests extends mocha_1.default {
    constructor() {
        super();
        this._customRunner = runner_1.createInstance();
        this._filesTotal = 0;
        this._reporterName = null;
        this._reporterOptions = null;
        // prevent uncaught exception listeners count warning
        process.setMaxListeners(0);
    }
    addFile(file) {
        watcher_1.addTest(file);
        this._filesTotal++;
        return this;
    }
    reporter(reporterName, reporterOptions) {
        if (reporterName === undefined) {
            return super.reporter.call(this, reporterName, reporterOptions);
        }
        this._reporterName = reporterName;
        this._reporterOptions = reporterOptions;
        return this;
    }
    setOwnOptions({ maxParallel, retry }) {
        watcher_1.setOptions({
            maxParallelTests: maxParallel,
            retryCount: retry
        });
    }
    run(callback) {
        this._customRunner.on('end', ({ failsOccured, reporter }) => {
            if (reporter.done) {
                reporter.done(failsOccured, callback);
            }
            else {
                callback(failsOccured);
            }
        });
        watcher_1.runTests({
            options: Object.assign({}, {
                reporterName: this._reporterName,
                reporterOptions: this._reporterOptions,
                reporter: reporter_1.default,
                testsLength: this._filesTotal
            }),
            throttledCalls: this._throttledCalls
        });
        return this._customRunner;
    }
}
Object.keys(mocha_1.default.prototype).forEach(key => {
    if (typeof mocha_1.default.prototype[key] !== 'function') {
        return;
    }
    // we have our own implementations of these methods
    // other methods should be saved and re-applied during runTests()
    if (key === 'run' || key === 'addFile' || key === 'reporter') {
        return;
    }
    MochaParallelTests.prototype[key] = function (...args) {
        // mocha calls some of its methods inside constructor
        // so MochaParallelTests own constructor function can still be in progress here
        this._throttledCalls = this._throttledCalls || [];
        this._throttledCalls.push({
            args,
            method: key
        });
        return this;
    };
});
exports.default = MochaParallelTests;
//# sourceMappingURL=api.js.map