'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const assert_1 = require("assert");
const path_1 = require("path");
const reporter_1 = require("./lib/reporter");
const runner_1 = require("./lib/runner");
const prepare_require_1 = require("./lib/utils/prepare-require");
const require_cache_watcher_1 = require("./lib/utils/require-cache-watcher");
const hooks_1 = require("./lib/utils/hooks");
const watcher_1 = require("./lib/watcher");
// files lookup in mocha is complex, so it's better to just run original code
const utils_1 = require("mocha/lib/utils");
const process_require_option_1 = require("./lib/utils/process-require-option");
function binHelper(options) {
    process.setMaxListeners(0);
    if (typeof options.compilers === 'string') {
        options.compilers = [options.compilers];
    }
    const extensions = ['js'];
    (options.compilers || []).forEach(compiler => {
        const [ext, mod] = compiler.split(':');
        let compilerMod = mod;
        if (mod[0] === '.') {
            compilerMod = path_1.default.join(process.cwd(), mod);
        }
        require(prepare_require_1.default(compilerMod));
        extensions.push(ext);
    });
    // require --require'd files
    process_require_option_1.default(options);
    // default files to test/*.{js,coffee}
    const patterns = (options._ || []).slice(2);
    if (!patterns.length) {
        patterns.push('test');
    }
    // get test files with original mocha utils.lookupFiles() function
    let files = [];
    patterns.forEach(testPath => {
        try {
            files = files.concat(utils_1.lookupFiles(testPath, extensions, options.recursive));
        }
        catch (ex) {
            if (ex.message.startsWith('cannot resolve path')) {
                console.error(`Warning: Could not find any test files matching pattern: ${testPath}`); // eslint-disable-line no-console
                return;
            }
            throw ex;
        }
    });
    assert_1.default(files.length, 'No test files found');
    // time to create our own runner
    const customRunner = runner_1.createInstance();
    // watcher monitors running files
    watcher_1.setOptions({
        maxParallelTests: options.maxParallel,
        retryCount: options.retry
    });
    // require(testFile) needs some global hooks (describe, it etc)
    hooks_1.patch();
    const cacheWatcher = new require_cache_watcher_1.default;
    cacheWatcher.start();
    files.forEach(file => {
        // does this file have a syntax error?
        // require() will show that
        const absFilePath = path_1.default.resolve(file);
        require(absFilePath);
        watcher_1.addTest(absFilePath);
    });
    // okay, all files are valid JavaScript
    // now it's time for mocha to set its own global hooks
    hooks_1.restore();
    // also we need to delete files from require.cache
    // which are involved into all tests
    const cacheMark = cacheWatcher.getStateMark();
    cacheWatcher.flushRequireCache(cacheMark);
    watcher_1.runTests({
        options: Object.assign({}, options, {
            reporterName: options.R || options.reporter,
            reporter: reporter_1.default,
            testsLength: files.length
        })
    });
    return new Promise((resolve) => {
        customRunner.on('end', resolve);
    });
}
exports.default = binHelper;
//# sourceMappingURL=bin-helper.js.map